//---------------------------------------------------------------------------
// Copyright (C) 2000 Dallas Semiconductor Corporation, All Rights Reserved.
// 
// Permission is hereby granted, free of charge, to any person obtaining a 
// copy of this software and associated documentation files (the "Software"), 
// to deal in the Software without restriction, including without limitation 
// the rights to use, copy, modify, merge, publish, distribute, sublicense, 
// and/or sell copies of the Software, and to permit persons to whom the 
// Software is furnished to do so, subject to the following conditions:
// 
// The above copyright notice and this permission notice shall be included 
// in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS 
// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF 
// MERCHANTABILITY,  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. 
// IN NO EVENT SHALL DALLAS SEMICONDUCTOR BE LIABLE FOR ANY CLAIM, DAMAGES 
// OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, 
// ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR 
// OTHER DEALINGS IN THE SOFTWARE.
// 
// Except as contained in this notice, the name of Dallas Semiconductor 
// shall not be used except as stated in the Dallas Semiconductor 
// Branding Policy. 
//--------------------------------------------------------------------------
//
//  Starter.C - The main subroutine call that initializes all of the calls.

#include <Pilot.h>
#include <SysEvtMgr.h>
#include <Hardware.h>
#include <stdio.h>
#include <string.h>
#include "common.h"
#include "sysall.h"
#include "StarterRsc.h"
#include "ownet.h"


// External Functions	
extern int  owAcquire(int,char *, char *);
extern int  owFirst(int,int,int);
extern int  owNext(int,int,int);
extern void owRelease(int,char *);
extern void owSerialNum(int,uchar *, int);
extern void msDelay(int);
extern long msGettick(void);

// local funcitons
static Word StartApplication(void);
void PrintSerialNum(int,int);
void   ClearScreen(int);


DWord PilotMain(Word cmd, char *cmdPBP, Word launchflags)
{
   	Word error;
   
	char return_msg[128];
	int portnum = 0;
	int rslt,cnt;
	EventType event;

   	if(cmd == sysAppLaunchCmdNormalLaunch)
   	{
      	error = StartApplication();
      	if(error) return error;
    
   		if (!owAcquire(portnum,"0",return_msg))
   		{  
   			WinDrawChars((char *) "didn't acq",10,55,110);
      		return 0;
   		}
   		else
   		{
   			do
   			{
 	  			WinDrawChars((char *) "LIST OF BUTTONS",15,45,20);
      			cnt = 0;

      			// find the first device (all devices not just alarming)
      			rslt = owFirst(portnum, TRUE, FALSE);
            	
      			while (rslt)
      			{
         			// print the device number
         			cnt++;

         			// print the Serial Number of the device just found
         			PrintSerialNum(portnum, cnt-1);

         			// find the next device
         			rslt = owNext(portnum, TRUE, FALSE);
      			}
      			
      			ClearScreen(cnt);
      			WinDrawChars((char *) "PRESS TO EXIT",13,10,140);
      			
      			EvtGetEvent(&event,1);
      		
      		} while(event.eType != penDownEvent);
	  	}

   	  	// release the 1-Wire Net	  
	  	owRelease(portnum, return_msg);

	}   
	     
    return 0;   
}

//---------------------------------------------------------------------
static Word StartApplication(void)
{
   FrmGotoForm(MainForm);  
   return 0;
}


//----------------------------------------------------------------------
//  Read and print the Serial Number.
//
void PrintSerialNum(int portnum, int cnt)
{
   uchar serial_num[8];
   char printsn[17];
   char tempstr[9];
   int i;

   owSerialNum(portnum,serial_num,TRUE);

   for (i=7; i>=0; i--)
   {
   	StrPrintF(tempstr, "%2X", serial_num[i]);
   	printsn[(7-i)*2] = tempstr[6];
   	printsn[(7-i)*2+1] = tempstr[7];
   }

	WinDrawChars(printsn,16,45,40+(cnt*10));
}


//---------------------------------------------------------------------
// Clears the palm pilot screen of all text
void ClearScreen(int row)
{
	int i;

	for(i=row;i<15;i++)
		WinDrawChars((char *) "                                                                           ",75,10,40+(i*10));
}
