//---------------------------------------------------------------------------
// Copyright (C) 2000 Dallas Semiconductor Corporation, All Rights Reserved.
// 
// Permission is hereby granted, free of charge, to any person obtaining a 
// copy of this software and associated documentation files (the "Software"), 
// to deal in the Software without restriction, including without limitation 
// the rights to use, copy, modify, merge, publish, distribute, sublicense, 
// and/or sell copies of the Software, and to permit persons to whom the 
// Software is furnished to do so, subject to the following conditions:
// 
// The above copyright notice and this permission notice shall be included 
// in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS 
// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF 
// MERCHANTABILITY,  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. 
// IN NO EVENT SHALL DALLAS SEMICONDUCTOR BE LIABLE FOR ANY CLAIM, DAMAGES 
// OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, 
// ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR 
// OTHER DEALINGS IN THE SOFTWARE.
// 
// Except as contained in this notice, the name of Dallas Semiconductor 
// shall not be used except as stated in the Dallas Semiconductor 
// Branding Policy. 
//--------------------------------------------------------------------------
//
//  Starter.C - The main subroutine call that initializes all of the calls.

#include <Pilot.h>
#include <SysEvtMgr.h>
#include <Hardware.h>
#include <stdio.h>
#include <string.h>
#include "StarterRsc.h"
#include "common.h"
#include "sysall.h"
#include "ownet.h"
#include "thermo21.h"


// External Functions	
extern int  owAcquire(int,char *, char *);
extern int  owFirst(int,int,int);
extern int  owNext(int,int,int);
extern void owRelease(int,char *);
extern void owSerialNum(int,uchar *, int);
extern void msDelay(int);
extern long msGettick(void);
extern int FindDevices(int,uchar FamilySN[][8],int,int);
extern int owReadPacketStd(int,int,int,uchar *);
extern int owWritePacketStd(int,int,uchar *,int,int,int);   
extern int ReadThermoStatus(int,uchar *,ThermoStateType *, FILE *);
extern void  InterpretStatus(MissionStatus *);
extern void  PrintMissionStatus(MissionStatus *, int, char *);
extern int  owSpeed(int,int);

// local funcitons
static Word StartApplication(void);
void   ClearScreen(void);

// Local Variables
#define MAXDEVICES 	20


DWord PilotMain(Word cmd, char *cmdPBP, Word launchflags)
{
   	Word error;
   
	char return_msg[128];
	int portnum = 0;
	int i,j,numdev;
	uchar family[MAXDEVICES][8];
	uchar tempfam[8];
	ThermoStateType ThermoState;
	char *str = NULL;
	int ConvertToF = TRUE;
	int exit_out = TRUE;
	int notclear = TRUE;
	FILE temp;
	EventType event;
	

   	if(cmd == sysAppLaunchCmdNormalLaunch)
   	{
      	error = StartApplication();
      	if(error) 
      		return error;
      	    
   		if (!owAcquire(portnum,"0",return_msg))
   		{  
   			WinDrawChars((char *) "Didn't Acquire",14,10,40);
   			msDelay(5000);
      		return 1;
   		}
   		else
   		{
   			do
   			{
   			    owSpeed(portnum,MODE_NORMAL);
   				numdev = FindDevices(portnum,&family[0],THERMO_FAM,MAXDEVICES);
   			   			
   				if(numdev == 0)
   				{
   					if(notclear)
   					{
   						ClearScreen();
   						notclear = FALSE;
   					}
   						
   					WinDrawChars((char *) "Thermochron not present on 1-Wire",33,10,10);
					WinDrawChars((char *) "PRESS TO EXIT OR ADD DS1921",27,10,20);
   				}
   				else
   				{
   					notclear = TRUE;
   					
   					for(i=0;i<numdev;i++)
   					{
   						ClearScreen();
   						for (j = 7; j >= 0; j--)
   						{
         					ThermoState.MissStat.serial_num[j] = family[i][j];
         					tempfam[j] = family[i][j];
         				}
	

						if(ReadThermoStatus(portnum, &family[i][0], &ThermoState, &temp))
						{
							InterpretStatus(&ThermoState.MissStat);

							PrintMissionStatus(&ThermoState.MissStat, ConvertToF, &str[0]);
						}   
						else
							WinDrawChars((char *) "Did not read",12,10,40);		

						WinDrawChars((char *) "PRESS TO CONTINUE",17,10,140);
						
						do
						{
							EvtGetEvent(&event,1);
						} while(event.eType != penDownEvent);
						
						
					}	

				}
				
				EvtGetEvent(&event,1);
				
			} while( (event.eType != penDownEvent) || !exit_out);
			
   	  		// release the 1-Wire Net	  
	  		owRelease(portnum, return_msg);
		}
		
	}   
	     
    return 0;   
}

//---------------------------------------------------------------------
static Word StartApplication(void)
{
   FrmGotoForm(MainForm);  
   return 0;
}


//---------------------------------------------------------------------
// Clears the palm pilot screen of all text
void ClearScreen(void)
{
	int i;
	
	for(i=0;i<15;i++)
		WinDrawChars((char *) "                                                                           ",75,10,i*10);
}
